@@ -1,7 +1,7 @@
 import tensorflow as tf
 
 
-def get_lr_callback(batch_size=8, lr_start=0.000005, lr_max=0.00000125, lr_min=0.000001, lr_ramp_ep=5, lr_sus_ep=0, lr_decay=0.8):
+def get_lr_callback(lr_start=0.000005, lr_max=0.00000125, lr_min=0.000001, lr_ramp_ep=5, lr_sus_ep=0, lr_decay=0.8):
     """ Train schedule for transfer learning. The learning rate starts near zero, then increases to a maximum, then decays over time.
         A good practice to follow is to increase maximum learning rate as batch size increase
 
